exceptiontools.MeasureContiguityError
=====================================

.. inheritance-diagram:: abjad.tools.exceptiontools.MeasureContiguityError.MeasureContiguityError
   :private-bases:

.. autoclass:: abjad.tools.exceptiontools.MeasureContiguityError.MeasureContiguityError

Special Methods
---------------

.. automethod:: abjad.tools.exceptiontools.MeasureContiguityError.MeasureContiguityError.__delattr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.MeasureContiguityError.MeasureContiguityError.__getitem__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.MeasureContiguityError.MeasureContiguityError.__getslice__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.MeasureContiguityError.MeasureContiguityError.__repr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.MeasureContiguityError.MeasureContiguityError.__setattr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.MeasureContiguityError.MeasureContiguityError.__setstate__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.MeasureContiguityError.MeasureContiguityError.__str__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.MeasureContiguityError.MeasureContiguityError.__unicode__

    Inherited from :py:class:`exceptions.BaseException`
